Changelog for adi.trash
=======================
 

0.4 (2018-03-02)
----------------

- 'ParseResult' object has no attribute 'endswith', fix error.  [amariscal]


0.3 (2017-07-27)
----------------

- Regard URL can contain parameters, fixes #3. [idgserpro]

- Add plone.api as a dependency. [idgserpro]


0.2 (2017-04-12)
----------------

- Merge PR from idgserpro, correct repo-URL. [ida]


0.1 (2015-11-01)
---------------

- Initial commit.
    
